@@ -364,7 +364,7 @@ compare_matches(const WacomDevice *a, const WacomDevice *b)
 
 	for (match_a = ma; *match_a; match_a++) {
 		int found = 0;
-		for (match_b = mb; !found && *mb; mb++) {
+		for (match_b = mb; !found && *match_b; match_b++) {
 			if (strcmp((*match_a)->match, (*match_b)->match) == 0)
 				found = 1;
 		}
@@ -544,13 +544,13 @@ libwacom_new_from_path(const WacomDeviceDatabase *db, const char *path, WacomFal
 	libwacom_update_match(ret, match);
 	libwacom_match_destroy(match);
 
-	g_free (name);
-
 	if (device) {
 		/* if unset, use the kernel flags. Could be unset as well. */
 		if (ret->integration_flags == WACOM_DEVICE_INTEGRATED_UNSET)
 			ret->integration_flags = integration_flags;
 
+		g_free (name);
+
 		return ret;
 	}
 
